@@ -1,12 +1,6 @@
 # -*- coding: utf-8 -*-
+""" Classical Memory """
 import ctypes
-from collections import Counter
-from ctypes.util import find_library
-import warnings
-import ctypes
-
-from qlazy.config import *
-from qlazy.error import *
 
 class CMem(ctypes.Structure):
     """ Classical Memory
@@ -39,7 +33,16 @@ class CMem(ctypes.Structure):
         obj = cmem_init(cmem_num)
         cmem = ctypes.cast(obj.value, ctypes.POINTER(cls)).contents
         return cmem
-            
+
+    def __str__(self):
+
+        return str(self.get_bits())
+
+    @property
+    def bits(self):
+        """ bit list of classical memory. """
+        return self.get_bits()
+
     def clone(self):
         """
         get the copy of the classical memory.
@@ -58,9 +61,26 @@ class CMem(ctypes.Structure):
         cmem = ctypes.cast(obj.value, ctypes.POINTER(self.__class__)).contents
         return cmem
 
+    def get_bits(self):
+        """
+        get bit list of the classical memory.
+
+        Parameters
+        ----------
+        None
+
+        Returns
+        -------
+        bits : numpy.ndarray (int)
+            bits array of the classical memory
+
+        """
+        bits = cmem_get_bits(self)
+        return bits
+
     def __del__(self):
-        
+
         cmem_free(self)
-        
+
 # c-library for qstate
-from qlazy.lib.cmem_c import *
+from qlazy.lib.cmem_c import cmem_init, cmem_copy, cmem_get_bits, cmem_free
